Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2865)

Unified Diff: chrome/browser/ui/gtk/collected_cookies_gtk.h

Issue 7831051: content: Move collected cookies constrained window to TabContentsWrapper. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Compile failures for everyone\! Created 9 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/gtk/browser_window_gtk.cc ('k') | chrome/browser/ui/gtk/collected_cookies_gtk.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/gtk/collected_cookies_gtk.h
diff --git a/chrome/browser/ui/gtk/collected_cookies_gtk.h b/chrome/browser/ui/gtk/collected_cookies_gtk.h
index 0b5563bd75dca7bafb32eda1de8d8c99d04d4c03..18d739e18b9b5a6fc24131faf79bb7610c219899 100644
--- a/chrome/browser/ui/gtk/collected_cookies_gtk.h
+++ b/chrome/browser/ui/gtk/collected_cookies_gtk.h
@@ -19,6 +19,7 @@
#include "ui/base/gtk/gtk_signal.h"
class CookiesTreeModel;
+class TabContentsWrapper;
// CollectedCookiesGtk is a dialog that displays the allowed and blocked
// cookies of the current tab contents. To display the dialog, invoke
@@ -26,10 +27,10 @@ class CookiesTreeModel;
// content settings tab helper.
class CollectedCookiesGtk : public ConstrainedWindowGtkDelegate,
- gtk_tree::TreeAdapter::Delegate,
- NotificationObserver {
+ public gtk_tree::TreeAdapter::Delegate,
+ public NotificationObserver {
public:
- CollectedCookiesGtk(GtkWindow* parent, TabContents* tab_contents);
+ CollectedCookiesGtk(GtkWindow* parent, TabContentsWrapper* wrapper);
// ConstrainedWindowGtkDelegate methods.
virtual GtkWidget* GetWidgetRoot();
@@ -112,8 +113,8 @@ class CollectedCookiesGtk : public ConstrainedWindowGtkDelegate,
// Displays information about selected cookie.
GtkWidget* cookie_info_view_;
- // The tab contents.
- TabContents* tab_contents_;
+ // The tab contents wrapper.
+ TabContentsWrapper* wrapper_;
bool status_changed_;
« no previous file with comments | « chrome/browser/ui/gtk/browser_window_gtk.cc ('k') | chrome/browser/ui/gtk/collected_cookies_gtk.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698